.. Pyperclip documentation master file, created by
   sphinx-quickstart on Fri Aug 15 22:34:37 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pyperclip's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   introduction.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

